[][src]Module act_zero::remote

Tools for creating actor proxies. These can be used to communicate with actors in a different process, or on a different machine.

Structs

Remote

Generic actor proxy type. Implements the actor trait when T implements Handle<M> for the message type corresponding to that actor trait.