[][src]Struct act_zero::remote::Remote

pub struct Remote<T>(_);

Generic actor proxy type. Implements the actor trait when T implements Handle<M> for the message type corresponding to that actor trait.

Implementations

impl<T> Remote<T>[src]

pub fn new(inner: T) -> Addr<Self>[src]

Construct an instance of the remote proxy. Typically the caller will then upcast() this actor ref into an Addr<dyn ActorTrait> to conceal the fact that this is a remote proxy.

pub fn inner(&self) -> &T[src]

Access the inner value.