SupportsTimers

Trait SupportsTimers 

pub trait SupportsTimers {
    type Delay: Future<Output = ()> + Send + 'static;

    // Required method
    fn delay(&self, deadline: Instant) -> Self::Delay;
}
Timers can be used on runtimes implementing this trait.

Required Associated Types

type Delay: Future<Output = ()> + Send + 'static

The type of future returned by delay.

Required Methods

fn delay(&self, deadline: Instant) -> Self::Delay

Create a future which will complete when the deadline is passed.

Implementors