[][src]Trait act_zero::utils::IntoResult

pub trait IntoResult<T, E> {
    fn into_result(self) -> Result<T, E>;
}

Helper trait for things which can be converted into a result. This is used to allow actor method implementations to optionally return a result.

Required methods

fn into_result(self) -> Result<T, E>

Perform the conversion.

Loading content...

Implementations on Foreign Types

impl<T, E> IntoResult<T, E> for Result<T, E>[src]

Loading content...

Implementors

impl<T, E> IntoResult<T, E> for T[src]

Loading content...