[−][src]Struct act_zero::async_fn::Closure
Rust does not support async closures, and is incapable of inferring the correct lifetimes
for closures returning an async move { ... } block which captures a non-'static argument
to the closure.
To solve this problem, we introduce this explicit closure type, which takes a stand-alone
async fn expecting two arguments, and binds the second argument to a closure "upvar"
passed in at construction.
Implementations
impl<R, F, P> Closure<R, F, P>[src]
pub fn new(fun: F, upvar: P) -> Self[src]
Constructor.
fun should implement ClosureFn or ClosureFnMut for this to be useful.