[−][src]Trait act_zero::async_fn::AsyncMutFnOnce
Trait for async methods which take &mut T as the argument type.
Associated Types
Loading content...Required methods
fn call(self, arg: &mut T) -> BoxFuture<'_, Self::Output>
Call this function.
fn call_boxed(self: Box<Self>, arg: &mut T) -> BoxFuture<'_, Self::Output>
Call this function when self is boxed.
Provided methods
fn map<G, R>(self, g: G) -> AsyncMap<Self, G> where
G: FnOnce(Self::Output, &mut T) -> R,
Self: Sized,
G: FnOnce(Self::Output, &mut T) -> R,
Self: Sized,
Similar to FutureExt::map, except the callback also has access to the argument.
fn bind_output(self, tx: Sender<Self::Output>) -> BindOutput<Self, Self::Output> where
Self: Sized,
Self: Sized,
Bind the output of this async function to this oneshot channel: when the future completes, the output will be sent on the channel.
Implementations on Foreign Types
impl<T, F> AsyncMutFnOnce<T> for Box<F> where
F: AsyncMutFnOnce<T>, [src]
F: AsyncMutFnOnce<T>,
type Output = F::Output
fn call(self, arg: &mut T) -> BoxFuture<'_, Self::Output>[src]
fn call_boxed(self: Box<Self>, arg: &mut T) -> BoxFuture<'_, Self::Output>[src]
Implementors
impl<F, G, T, R> AsyncMutFnOnce<T> for AsyncMap<F, G> where
F: AsyncMutFnOnce<T> + Send + 'static,
G: FnOnce(F::Output, &mut T) -> R + Send + 'static,
R: Send + 'static,
T: Send, [src]
F: AsyncMutFnOnce<T> + Send + 'static,
G: FnOnce(F::Output, &mut T) -> R + Send + 'static,
R: Send + 'static,
T: Send,
type Output = R
fn call(self, arg: &mut T) -> BoxFuture<'_, R>[src]
fn call_boxed(self: Box<Self>, arg: &mut T) -> BoxFuture<'_, Self::Output>[src]
impl<F, P, T, R> AsyncMutFnOnce<T> for Closure<R, F, P> where
F: for<'a> ClosureFnMut<'a, T, P, R>,
R: Send + 'static, [src]
F: for<'a> ClosureFnMut<'a, T, P, R>,
R: Send + 'static,
type Output = R
fn call(self, arg: &mut T) -> BoxFuture<'_, R>[src]
fn call_boxed(self: Box<Self>, arg: &mut T) -> BoxFuture<'_, Self::Output>[src]
impl<F, T, R> AsyncMutFnOnce<T> for BindOutput<F, R> where
F: AsyncMutFnOnce<T, Output = R>,
R: Send + 'static, [src]
F: AsyncMutFnOnce<T, Output = R>,
R: Send + 'static,