[−][src]Trait act_zero::async_fn::ClosureFnMut
We can't even directly express the lifetime bounds of an async fn directly, so we
are forced to introduce a trait just to write the required bounds.
This trait is for the case when the first argument is &mut T.
Associated Types
Loading content...Required methods
fn call_closure(self, arg1: &'a mut T, arg2: P) -> Self::Future
Call this async fn with two arguments.
Implementors
impl<'a, F, T, P, Fut, R> ClosureFnMut<'a, T, P, R> for F where
Fut: Future<Output = R> + Send + 'a,
T: 'a,
F: FnOnce(&'a mut T, P) -> Fut, [src]
Fut: Future<Output = R> + Send + 'a,
T: 'a,
F: FnOnce(&'a mut T, P) -> Fut,