[−][src]Module act_zero::remote
Tools for creating actor proxies. These can be used to communicate with actors in a different process, or on a different machine.
Structs
| Remote | Generic actor proxy type. Implements the actor trait when |
Tools for creating actor proxies. These can be used to communicate with actors in a different process, or on a different machine.
| Remote | Generic actor proxy type. Implements the actor trait when |