pub trait SupportsTimers { type Delay: Future<Output = ()> + Send + 'static; // Required method fn delay(&self, deadline: Instant) -> Self::Delay; }
Timers can be used on runtimes implementing this trait.
The type of future returned by delay.
delay
Create a future which will complete when the deadline is passed.