[−][src]Trait act_zero::utils::IntoResult
Helper trait for things which can be converted into a result. This is used to allow actor method implementations to optionally return a result.
Required methods
fn into_result(self) -> Result<T, E>
Perform the conversion.